Actions, Resources, and Condition Keys for AWS Health APIs and Notifications - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS Health APIs and Notifications

AWS Health APIs and Notifications (service prefix: `health` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Health APIs and Notifications
- Resource Types Defined by AWS Health APIs and Notifications
- Condition Keys for AWS Health APIs and Notifications

## Actions Defined by AWS Health APIs and Notifications

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
DescribeAffectedAccountsForOrganization | Gets a list of accounts that have been affected by the specified events in organization. | Read |  |  | organizations:ListAccounts
DescribeAffectedEntities | Gets a list of entities that have been affected by the specified events. | Read | event* |  |
| health:eventTypeCode health:service |
DescribeAffectedEntitiesForOrganization | Gets a list of entities that have been affected by the specified events and accounts in organization. | Read |  |  | organizations:ListAccounts
DescribeEntityAggregates | Returns the number of entities that are affected by each of the specified events. | Read |  |  |
DescribeEventAggregates | Returns the number of events of each event type (issue, scheduled change, and account notification). | Read |  |  |
DescribeEventDetails | Returns detailed information about one or more specified events. | Read | event* |  |
| health:eventTypeCode health:service |
DescribeEventDetailsForOrganization | Returns detailed information about one or more specified events for provided accounts in organization. | Read |  |  | organizations:ListAccounts
DescribeEventTypes | Returns the event types that meet the specified filter criteria. | Read |  |  |
DescribeEvents | Returns information about events that meet the specified filter criteria. | Read |  |  |
DescribeEventsForOrganization | Returns information about events that meet the specified filter criteria in organization. | Read |  |  | organizations:ListAccounts
DescribeHealthServiceStatusForOrganization | Returns the status of enabling or disabling the Organizational View feature | Permissions management |  |  | organizations:ListAccounts
DisableHealthServiceAccessForOrganization | Disables the Organizational View feature. | Permissions management |  |  | organizations:DisableAWSServiceAccess organizations:ListAccounts
EnableHealthServiceAccessForOrganization | Enables the Organizational View feature. | Permissions management |  |  | iam:CreateServiceLinkedRole organizations:EnableAWSServiceAccess organizations:ListAccounts

## Resource Types Defined by AWS Health APIs and Notifications

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
event | `arn:$ { Partition}:health:*::event/$ { Service}/$ { EventTypeCode}/*` |

## Condition Keys for AWS Health APIs and Notifications

AWS Health APIs and Notifications defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
health:eventTypeCode | The type of event. | String
health:service | The service of the event. | String